exclusion_criteria: exclusion_criteria
Description
Exclusion criteria
Usage
exclusion_criteria(data, cutoff = 0)
Value
A tibble with a brace of smaller tibbles, with each sub-tibble including a data frame after each one of the exclusion criteria -- mentioned in the multifear::chop_css function -- is applied.
Arguments
- data
a data object generated by the multics::chop_css function
- cutoff
cut off score
Details
Here the different exclusion criteria are applied to the provided data.