# Briefly define argument values that will be plugged in later on in the functions.
# We only use two trials as the function takes a long time to run.
data(example_data)
cs1 <- paste0("CSP", 1:2)
cs2 <- paste0("CSM", 1:2)
subj <- "id"
# Bayesian Repeated measures ANOVA without groups
rm_banova_mf(cs1 = cs1, cs2 = cs2, subj = subj,
data = example_data, time = TRUE)
Run the code above in your browser using DataLab